@@ -34,10 +34,9 @@ __EOF__
 fi
 
 exit 0
-
-diff -Naur a/attachment.cgi b/attachment.cgi
---- a/attachment.cgi	2010-05-17 18:47:29.000000000 +0200
-+++ b/attachment.cgi	2010-08-08 15:36:58.187003436 +0200
+diff -Naur bugzilla-srcdir.orig//attachment.cgi bugzilla-srcdir/attachment.cgi
+--- bugzilla-srcdir.orig//attachment.cgi	2010-11-12 10:26:24.156917777 +0100
++++ bugzilla-srcdir/attachment.cgi	2010-11-12 10:28:19.701917501 +0100
 @@ -130,7 +130,7 @@
    ThrowCodeError("unknown_action", { action => $action });
  }
@@ -91,7 +90,7 @@ diff -Naur a/attachment.cgi b/attachment.cgi
          }
      }
  
-@@ -624,7 +624,7 @@
+@@ -625,7 +625,7 @@
                  # Warn the user about the mid-air collision and ask them what to do.
                  $template->process("attachment/midair.html.tmpl", $vars)
                    || ThrowTemplateError($template->error());
@@ -100,9 +99,9 @@ diff -Naur a/attachment.cgi b/attachment.cgi
              }
          }
      }
-diff -Naur a/buglist.cgi b/buglist.cgi
---- a/buglist.cgi	2010-08-02 01:37:31.000000000 +0200
-+++ b/buglist.cgi	2010-08-08 15:36:58.190668330 +0200
+diff -Naur bugzilla-srcdir.orig//buglist.cgi bugzilla-srcdir/buglist.cgi
+--- bugzilla-srcdir.orig//buglist.cgi	2010-11-12 10:26:39.540915708 +0100
++++ bugzilla-srcdir/buglist.cgi	2010-11-12 10:28:19.705916808 +0100
 @@ -77,7 +77,7 @@
      $vars->{'url'} = $url;
      $template->process("global/message.html.tmpl", $vars)
@@ -139,9 +138,9 @@ diff -Naur a/buglist.cgi b/buglist.cgi
      }
  }
  
-diff -Naur a/Bugzilla/Auth/Login/CGI.pm b/Bugzilla/Auth/Login/CGI.pm
---- a/Bugzilla/Auth/Login/CGI.pm	2010-03-24 00:21:18.000000000 +0100
-+++ b/Bugzilla/Auth/Login/CGI.pm	2010-08-08 15:36:58.190668330 +0200
+diff -Naur bugzilla-srcdir.orig//Bugzilla/Auth/Login/CGI.pm bugzilla-srcdir/Bugzilla/Auth/Login/CGI.pm
+--- bugzilla-srcdir.orig//Bugzilla/Auth/Login/CGI.pm	2010-03-24 00:21:18.000000000 +0100
++++ bugzilla-srcdir/Bugzilla/Auth/Login/CGI.pm	2010-11-12 10:28:19.705916808 +0100
 @@ -65,7 +65,7 @@
      $template->process("account/auth/login.html.tmpl",
                         { 'target' => $cgi->url(-relative=>1) }) 
@@ -151,9 +150,9 @@ diff -Naur a/Bugzilla/Auth/Login/CGI.pm b/Bugzilla/Auth/Login/CGI.pm
  }
  
  1;
-diff -Naur a/Bugzilla/Bug.pm b/Bugzilla/Bug.pm
---- a/Bugzilla/Bug.pm	2010-08-04 02:49:23.000000000 +0200
-+++ b/Bugzilla/Bug.pm	2010-08-08 15:36:58.190668330 +0200
+diff -Naur bugzilla-srcdir.orig//Bugzilla/Bug.pm bugzilla-srcdir/Bugzilla/Bug.pm
+--- bugzilla-srcdir.orig//Bugzilla/Bug.pm	2010-10-28 17:35:01.000000000 +0200
++++ bugzilla-srcdir/Bugzilla/Bug.pm	2010-11-12 10:28:19.709917012 +0100
 @@ -1379,7 +1379,7 @@
              print $cgi->header();
              $template->process("bug/process/confirm-duplicate.html.tmpl", $vars)
@@ -172,10 +171,10 @@ diff -Naur a/Bugzilla/Bug.pm b/Bugzilla/Bug.pm
          }
      }
      else {
-diff -Naur a/Bugzilla/CGI.pm b/Bugzilla/CGI.pm
---- a/Bugzilla/CGI.pm	2010-07-15 19:34:25.000000000 +0200
-+++ b/Bugzilla/CGI.pm	2010-08-08 15:36:58.195002108 +0200
-@@ -396,7 +396,7 @@
+diff -Naur bugzilla-srcdir.orig//Bugzilla/CGI.pm bugzilla-srcdir/Bugzilla/CGI.pm
+--- bugzilla-srcdir.orig//Bugzilla/CGI.pm	2010-11-03 00:35:08.000000000 +0100
++++ bugzilla-srcdir/Bugzilla/CGI.pm	2010-11-12 10:28:19.709917012 +0100
+@@ -395,7 +395,7 @@
  
      # When using XML-RPC with mod_perl, we need the headers sent immediately.
      $self->r->rflush if $ENV{MOD_PERL};
@@ -184,7 +183,7 @@ diff -Naur a/Bugzilla/CGI.pm b/Bugzilla/CGI.pm
  }
  
  # Redirect to the urlbase version of the current URL.
-@@ -404,7 +404,7 @@
+@@ -403,7 +403,7 @@
      my $self = shift;
      my $path = $self->url('-path_info' => 1, '-query' => 1, '-relative' => 1);
      print $self->redirect('-location' => correct_urlbase() . $path);
@@ -193,9 +192,9 @@ diff -Naur a/Bugzilla/CGI.pm b/Bugzilla/CGI.pm
  }
  
  sub url_is_attachment_base {
-diff -Naur a/Bugzilla/DB/Mysql.pm b/Bugzilla/DB/Mysql.pm
---- a/Bugzilla/DB/Mysql.pm	2010-02-01 00:39:14.000000000 +0100
-+++ b/Bugzilla/DB/Mysql.pm	2010-08-08 15:36:58.195002108 +0200
+diff -Naur bugzilla-srcdir.orig//Bugzilla/DB/Mysql.pm bugzilla-srcdir/Bugzilla/DB/Mysql.pm
+--- bugzilla-srcdir.orig//Bugzilla/DB/Mysql.pm	2010-02-01 00:39:14.000000000 +0100
++++ bugzilla-srcdir/Bugzilla/DB/Mysql.pm	2010-11-12 10:28:19.709917012 +0100
 @@ -707,7 +707,7 @@
           Re-run checksetup.pl in interactive mode (without an 'answers' file)
           to continue.
@@ -205,9 +204,9 @@ diff -Naur a/Bugzilla/DB/Mysql.pm b/Bugzilla/DB/Mysql.pm
              }
              else {
                  print "         Press Enter to continue or Ctrl-C to exit...";
-diff -Naur a/Bugzilla/DB.pm b/Bugzilla/DB.pm
---- a/Bugzilla/DB.pm	2010-08-02 03:34:28.000000000 +0200
-+++ b/Bugzilla/DB.pm	2010-08-08 15:36:58.195002108 +0200
+diff -Naur bugzilla-srcdir.orig//Bugzilla/DB.pm bugzilla-srcdir/Bugzilla/DB.pm
+--- bugzilla-srcdir.orig//Bugzilla/DB.pm	2010-08-02 03:34:28.000000000 +0200
++++ bugzilla-srcdir/Bugzilla/DB.pm	2010-11-12 10:28:19.713916614 +0100
 @@ -155,7 +155,7 @@
      $command
  
@@ -244,9 +243,9 @@ diff -Naur a/Bugzilla/DB.pm b/Bugzilla/DB.pm
      }
      return $dbh;    
  }
-diff -Naur a/Bugzilla/Error.pm b/Bugzilla/Error.pm
---- a/Bugzilla/Error.pm	2010-04-01 03:17:35.000000000 +0200
-+++ b/Bugzilla/Error.pm	2010-08-08 15:36:58.195002108 +0200
+diff -Naur bugzilla-srcdir.orig//Bugzilla/Error.pm bugzilla-srcdir/Bugzilla/Error.pm
+--- bugzilla-srcdir.orig//Bugzilla/Error.pm	2010-04-01 03:17:35.000000000 +0200
++++ bugzilla-srcdir/Bugzilla/Error.pm	2010-11-12 10:28:19.713916614 +0100
 @@ -136,7 +136,7 @@
              }
          }
@@ -265,9 +264,9 @@ diff -Naur a/Bugzilla/Error.pm b/Bugzilla/Error.pm
  }
  
  1;
-diff -Naur a/Bugzilla/Install/Localconfig.pm b/Bugzilla/Install/Localconfig.pm
---- a/Bugzilla/Install/Localconfig.pm	2010-04-22 20:22:50.000000000 +0200
-+++ b/Bugzilla/Install/Localconfig.pm	2010-08-08 15:36:58.199002105 +0200
+diff -Naur bugzilla-srcdir.orig//Bugzilla/Install/Localconfig.pm bugzilla-srcdir/Bugzilla/Install/Localconfig.pm
+--- bugzilla-srcdir.orig//Bugzilla/Install/Localconfig.pm	2010-04-22 20:22:50.000000000 +0200
++++ bugzilla-srcdir/Bugzilla/Install/Localconfig.pm	2010-11-12 10:28:19.713916614 +0100
 @@ -393,7 +393,7 @@
  checksetup.pl:  $newstuff
  
@@ -277,10 +276,10 @@ diff -Naur a/Bugzilla/Install/Localconfig.pm b/Bugzilla/Install/Localconfig.pm
      }
  
      # Reset the cache for Bugzilla->localconfig so that it will be re-read
-diff -Naur a/Bugzilla/Search/Quicksearch.pm b/Bugzilla/Search/Quicksearch.pm
---- a/Bugzilla/Search/Quicksearch.pm	2010-08-02 04:19:36.000000000 +0200
-+++ b/Bugzilla/Search/Quicksearch.pm	2010-08-08 15:36:58.199002105 +0200
-@@ -227,7 +227,7 @@
+diff -Naur bugzilla-srcdir.orig//Bugzilla/Search/Quicksearch.pm bugzilla-srcdir/Bugzilla/Search/Quicksearch.pm
+--- bugzilla-srcdir.orig//Bugzilla/Search/Quicksearch.pm	2010-09-21 20:02:13.000000000 +0200
++++ bugzilla-srcdir/Bugzilla/Search/Quicksearch.pm	2010-11-12 10:28:19.713916614 +0100
+@@ -230,7 +230,7 @@
          # Single bug number; shortcut to show_bug.cgi.
          print $cgi->redirect(
              -uri => correct_urlbase() . "show_bug.cgi?id=$searchstring");
@@ -289,7 +288,7 @@ diff -Naur a/Bugzilla/Search/Quicksearch.pm b/Bugzilla/Search/Quicksearch.pm
      }
      else {
          # List of bug numbers.
-@@ -247,7 +247,7 @@
+@@ -250,7 +250,7 @@
          if ($is_alias) {
              print Bugzilla->cgi->redirect(
                  -uri => correct_urlbase() . "show_bug.cgi?id=$alias");
@@ -298,9 +297,9 @@ diff -Naur a/Bugzilla/Search/Quicksearch.pm b/Bugzilla/Search/Quicksearch.pm
          }
      }
  }
-diff -Naur a/Bugzilla/Token.pm b/Bugzilla/Token.pm
---- a/Bugzilla/Token.pm	2009-12-31 13:53:19.000000000 +0100
-+++ b/Bugzilla/Token.pm	2010-08-08 15:36:58.199002105 +0200
+diff -Naur bugzilla-srcdir.orig//Bugzilla/Token.pm bugzilla-srcdir/Bugzilla/Token.pm
+--- bugzilla-srcdir.orig//Bugzilla/Token.pm	2009-12-31 13:53:19.000000000 +0100
++++ bugzilla-srcdir/Bugzilla/Token.pm	2010-11-12 10:28:19.717916713 +0100
 @@ -218,7 +218,7 @@
          print Bugzilla->cgi->header();
          $template->process('global/confirm-action.html.tmpl', $vars)
@@ -319,9 +318,9 @@ diff -Naur a/Bugzilla/Token.pm b/Bugzilla/Token.pm
      }
      return 1;
  }
-diff -Naur a/Bugzilla/User.pm b/Bugzilla/User.pm
---- a/Bugzilla/User.pm	2010-02-18 01:34:42.000000000 +0100
-+++ b/Bugzilla/User.pm	2010-08-08 15:36:58.199002105 +0200
+diff -Naur bugzilla-srcdir.orig//Bugzilla/User.pm bugzilla-srcdir/Bugzilla/User.pm
+--- bugzilla-srcdir.orig//Bugzilla/User.pm	2010-02-18 01:34:42.000000000 +0100
++++ bugzilla-srcdir/Bugzilla/User.pm	2010-11-12 10:28:19.717916713 +0100
 @@ -1322,7 +1322,7 @@
  
      $template->process("global/confirm-user-match.html.tmpl", $vars)
@@ -331,9 +330,9 @@ diff -Naur a/Bugzilla/User.pm b/Bugzilla/User.pm
  
  }
  
-diff -Naur a/Bugzilla.pm b/Bugzilla.pm
---- a/Bugzilla.pm	2010-08-04 23:49:23.000000000 +0200
-+++ b/Bugzilla.pm	2010-08-08 15:36:58.203025055 +0200
+diff -Naur bugzilla-srcdir.orig//Bugzilla.pm bugzilla-srcdir/Bugzilla.pm
+--- bugzilla-srcdir.orig//Bugzilla.pm	2010-11-12 10:27:20.664915051 +0100
++++ bugzilla-srcdir/Bugzilla.pm	2010-11-12 10:28:19.721916586 +0100
 @@ -134,7 +134,7 @@
          if (lsearch(SHUTDOWNHTML_EXIT_SILENTLY, basename($0)) > -1
              && !i_am_cgi())
@@ -352,9 +351,9 @@ diff -Naur a/Bugzilla.pm b/Bugzilla.pm
      }
  }
  
-diff -Naur a/chart.cgi b/chart.cgi
---- a/chart.cgi	2009-10-24 07:21:06.000000000 +0200
-+++ b/chart.cgi	2010-08-08 15:36:58.203025055 +0200
+diff -Naur bugzilla-srcdir.orig//chart.cgi bugzilla-srcdir/chart.cgi
+--- bugzilla-srcdir.orig//chart.cgi	2010-11-12 10:26:25.625929357 +0100
++++ bugzilla-srcdir/chart.cgi	2010-11-12 10:28:19.721916586 +0100
 @@ -76,7 +76,7 @@
      my $params = $cgi->canonicalise_query("format", "ctype", "action");
      print "Location: query.cgi?format=" . $cgi->param('query_format') .
@@ -382,9 +381,9 @@ diff -Naur a/chart.cgi b/chart.cgi
  
  # Find any selected series and return either the first or all of them.
  sub getAndValidateSeriesIDs {
-diff -Naur a/colchange.cgi b/colchange.cgi
---- a/colchange.cgi	2010-05-19 18:34:05.000000000 +0200
-+++ b/colchange.cgi	2010-08-08 15:36:58.203025055 +0200
+diff -Naur bugzilla-srcdir.orig//colchange.cgi bugzilla-srcdir/colchange.cgi
+--- bugzilla-srcdir.orig//colchange.cgi	2010-11-12 10:26:23.916940016 +0100
++++ bugzilla-srcdir/colchange.cgi	2010-11-12 10:28:19.721916586 +0100
 @@ -164,12 +164,12 @@
      }
      else {
@@ -400,9 +399,9 @@ diff -Naur a/colchange.cgi b/colchange.cgi
  }
  
  if (defined $cgi->param('columnlist')) {
-diff -Naur a/config.cgi b/config.cgi
---- a/config.cgi	2010-03-18 15:02:54.000000000 +0100
-+++ b/config.cgi	2010-08-08 15:36:58.203025055 +0200
+diff -Naur bugzilla-srcdir.orig//config.cgi bugzilla-srcdir/config.cgi
+--- bugzilla-srcdir.orig//config.cgi	2010-11-12 10:26:39.496917725 +0100
++++ bugzilla-srcdir/config.cgi	2010-11-12 10:28:19.721916586 +0100
 @@ -161,5 +161,5 @@
                              -type => $format->{'ctype'});
          print $output;
@@ -410,9 +409,9 @@ diff -Naur a/config.cgi b/config.cgi
 -    exit;
 +    exit(0);
  }
-diff -Naur a/contrib/recode.pl b/contrib/recode.pl
---- a/contrib/recode.pl	2009-02-20 22:54:16.000000000 +0100
-+++ b/contrib/recode.pl	2010-08-08 15:36:58.203025055 +0200
+diff -Naur bugzilla-srcdir.orig//contrib/recode.pl bugzilla-srcdir/contrib/recode.pl
+--- bugzilla-srcdir.orig//contrib/recode.pl	2010-11-12 10:26:25.192920218 +0100
++++ bugzilla-srcdir/contrib/recode.pl	2010-11-12 10:28:19.721916586 +0100
 @@ -154,7 +154,7 @@
    $^X install-module.pl Encode::Detect
  
@@ -422,9 +421,9 @@ diff -Naur a/contrib/recode.pl b/contrib/recode.pl
      }
  
      import Encode::Detect::Detector qw(detect);
-diff -Naur a/contrib/sendbugmail.pl b/contrib/sendbugmail.pl
---- a/contrib/sendbugmail.pl	2010-03-08 03:47:38.000000000 +0100
-+++ b/contrib/sendbugmail.pl	2010-08-08 15:36:58.203025055 +0200
+diff -Naur bugzilla-srcdir.orig//contrib/sendbugmail.pl bugzilla-srcdir/contrib/sendbugmail.pl
+--- bugzilla-srcdir.orig//contrib/sendbugmail.pl	2010-11-12 10:26:25.008928823 +0100
++++ bugzilla-srcdir/contrib/sendbugmail.pl	2010-11-12 10:28:19.721916586 +0100
 @@ -23,7 +23,7 @@
  
  sub usage {
@@ -434,9 +433,9 @@ diff -Naur a/contrib/sendbugmail.pl b/contrib/sendbugmail.pl
  }
  
  if (($#ARGV < 1) || ($#ARGV > 2)) {
-diff -Naur a/contrib/syncLDAP.pl b/contrib/syncLDAP.pl
---- a/contrib/syncLDAP.pl	2008-07-07 11:01:51.000000000 +0200
-+++ b/contrib/syncLDAP.pl	2010-08-08 15:36:58.203025055 +0200
+diff -Naur bugzilla-srcdir.orig//contrib/syncLDAP.pl bugzilla-srcdir/contrib/syncLDAP.pl
+--- bugzilla-srcdir.orig//contrib/syncLDAP.pl	2010-11-12 10:26:25.208930927 +0100
++++ bugzilla-srcdir/contrib/syncLDAP.pl	2010-11-12 10:28:19.721916586 +0100
 @@ -70,7 +70,7 @@
           print " -c No create, don't create users, which are in LDAP but not in Bugzilla\n";
           print " -q Quiet mode, give less output\n";
@@ -482,9 +481,9 @@ diff -Naur a/contrib/syncLDAP.pl b/contrib/syncLDAP.pl
  }
     
  my %val = %{ $mesg->as_struct };
-diff -Naur a/createaccount.cgi b/createaccount.cgi
---- a/createaccount.cgi	2007-11-11 23:03:16.000000000 +0100
-+++ b/createaccount.cgi	2010-08-08 15:36:58.203025055 +0200
+diff -Naur bugzilla-srcdir.orig//createaccount.cgi bugzilla-srcdir/createaccount.cgi
+--- bugzilla-srcdir.orig//createaccount.cgi	2010-11-12 10:26:23.609427775 +0100
++++ bugzilla-srcdir/createaccount.cgi	2010-11-12 10:28:19.721916586 +0100
 @@ -74,7 +74,7 @@
  
      $template->process("account/created.html.tmpl", $vars)
@@ -494,9 +493,9 @@ diff -Naur a/createaccount.cgi b/createaccount.cgi
  }
  
  # Show the standard "would you like to create an account?" form.
-diff -Naur a/describecomponents.cgi b/describecomponents.cgi
---- a/describecomponents.cgi	2009-05-21 10:43:23.000000000 +0200
-+++ b/describecomponents.cgi	2010-08-08 15:36:58.203025055 +0200
+diff -Naur bugzilla-srcdir.orig//describecomponents.cgi bugzilla-srcdir/describecomponents.cgi
+--- bugzilla-srcdir.orig//describecomponents.cgi	2010-11-12 10:26:23.441434910 +0100
++++ bugzilla-srcdir/describecomponents.cgi	2010-11-12 10:28:19.721916586 +0100
 @@ -70,7 +70,7 @@
  
          $template->process("global/choose-product.html.tmpl", $vars)
@@ -506,9 +505,9 @@ diff -Naur a/describecomponents.cgi b/describecomponents.cgi
      }
  
      # If there is only one product available and the user didn't specify
-diff -Naur a/editclassifications.cgi b/editclassifications.cgi
---- a/editclassifications.cgi	2009-01-02 14:59:22.000000000 +0100
-+++ b/editclassifications.cgi	2010-08-08 15:36:58.207008899 +0200
+diff -Naur bugzilla-srcdir.orig//editclassifications.cgi bugzilla-srcdir/editclassifications.cgi
+--- bugzilla-srcdir.orig//editclassifications.cgi	2010-11-12 10:26:24.104928811 +0100
++++ bugzilla-srcdir/editclassifications.cgi	2010-11-12 10:28:19.721916586 +0100
 @@ -51,7 +51,7 @@
      print $cgi->header();
      $template->process("admin/classifications/$action.html.tmpl", $vars)
@@ -518,9 +517,9 @@ diff -Naur a/editclassifications.cgi b/editclassifications.cgi
  }
  
  #
-diff -Naur a/editcomponents.cgi b/editcomponents.cgi
---- a/editcomponents.cgi	2010-02-01 00:33:30.000000000 +0100
-+++ b/editcomponents.cgi	2010-08-08 15:36:58.207008899 +0200
+diff -Naur bugzilla-srcdir.orig//editcomponents.cgi bugzilla-srcdir/editcomponents.cgi
+--- bugzilla-srcdir.orig//editcomponents.cgi	2010-11-12 10:26:24.920955767 +0100
++++ bugzilla-srcdir/editcomponents.cgi	2010-11-12 10:28:19.721916586 +0100
 @@ -80,7 +80,7 @@
  
      $template->process("admin/components/select-product.html.tmpl", $vars)
@@ -593,9 +592,9 @@ diff -Naur a/editcomponents.cgi b/editcomponents.cgi
  }
  
  #
-diff -Naur a/editflagtypes.cgi b/editflagtypes.cgi
---- a/editflagtypes.cgi	2009-11-23 23:40:54.000000000 +0100
-+++ b/editflagtypes.cgi	2010-08-08 15:36:58.207008899 +0200
+diff -Naur bugzilla-srcdir.orig//editflagtypes.cgi bugzilla-srcdir/editflagtypes.cgi
+--- bugzilla-srcdir.orig//editflagtypes.cgi	2010-11-12 10:26:39.456938968 +0100
++++ bugzilla-srcdir/editflagtypes.cgi	2010-11-12 10:28:19.721916586 +0100
 @@ -73,7 +73,7 @@
  if (@categoryActions = grep(/^categoryAction-.+/, $cgi->param())) {
      $categoryActions[0] =~ s/^categoryAction-//;
@@ -614,9 +613,9 @@ diff -Naur a/editflagtypes.cgi b/editflagtypes.cgi
  
  ################################################################################
  # Functions
-diff -Naur a/editgroups.cgi b/editgroups.cgi
---- a/editgroups.cgi	2009-12-31 13:48:21.000000000 +0100
-+++ b/editgroups.cgi	2010-08-08 15:36:58.207008899 +0200
+diff -Naur bugzilla-srcdir.orig//editgroups.cgi bugzilla-srcdir/editgroups.cgi
+--- bugzilla-srcdir.orig//editgroups.cgi	2010-11-12 10:26:25.248917828 +0100
++++ bugzilla-srcdir/editgroups.cgi	2010-11-12 10:28:19.721916586 +0100
 @@ -157,7 +157,7 @@
      print $cgi->header();
      $template->process("admin/groups/list.html.tmpl", $vars)
@@ -698,9 +697,9 @@ diff -Naur a/editgroups.cgi b/editgroups.cgi
  }
  
  
-diff -Naur a/editkeywords.cgi b/editkeywords.cgi
---- a/editkeywords.cgi	2010-07-05 03:34:38.000000000 +0200
-+++ b/editkeywords.cgi	2010-08-08 15:36:58.207008899 +0200
+diff -Naur bugzilla-srcdir.orig//editkeywords.cgi bugzilla-srcdir/editkeywords.cgi
+--- bugzilla-srcdir.orig//editkeywords.cgi	2010-11-12 10:26:24.000917760 +0100
++++ bugzilla-srcdir/editkeywords.cgi	2010-11-12 10:28:19.721916586 +0100
 @@ -62,7 +62,7 @@
      $template->process("admin/keywords/list.html.tmpl", $vars)
        || ThrowTemplateError($template->error());
@@ -764,9 +763,9 @@ diff -Naur a/editkeywords.cgi b/editkeywords.cgi
  }
  
  ThrowCodeError("action_unrecognized", $vars);
-diff -Naur a/editmilestones.cgi b/editmilestones.cgi
---- a/editmilestones.cgi	2008-01-28 00:14:14.000000000 +0100
-+++ b/editmilestones.cgi	2010-08-08 15:36:58.207008899 +0200
+diff -Naur bugzilla-srcdir.orig//editmilestones.cgi bugzilla-srcdir/editmilestones.cgi
+--- bugzilla-srcdir.orig//editmilestones.cgi	2010-11-12 10:26:24.040930488 +0100
++++ bugzilla-srcdir/editmilestones.cgi	2010-11-12 10:28:19.721916586 +0100
 @@ -77,7 +77,7 @@
  
      $template->process("admin/milestones/select-product.html.tmpl", $vars)
@@ -839,9 +838,9 @@ diff -Naur a/editmilestones.cgi b/editmilestones.cgi
  }
  
  #
-diff -Naur a/editproducts.cgi b/editproducts.cgi
---- a/editproducts.cgi	2009-12-18 00:31:52.000000000 +0100
-+++ b/editproducts.cgi	2010-08-08 15:36:58.211002100 +0200
+diff -Naur bugzilla-srcdir.orig//editproducts.cgi bugzilla-srcdir/editproducts.cgi
+--- bugzilla-srcdir.orig//editproducts.cgi	2010-11-12 10:26:24.176934711 +0100
++++ bugzilla-srcdir/editproducts.cgi	2010-11-12 10:28:19.721916586 +0100
 @@ -95,7 +95,7 @@
  
      $template->process("admin/products/list-classifications.html.tmpl", $vars)
@@ -941,9 +940,9 @@ diff -Naur a/editproducts.cgi b/editproducts.cgi
  }
  
  #
-diff -Naur a/editusers.cgi b/editusers.cgi
---- a/editusers.cgi	2009-12-30 15:28:38.000000000 +0100
-+++ b/editusers.cgi	2010-08-08 15:36:58.211002100 +0200
+diff -Naur bugzilla-srcdir.orig//editusers.cgi bugzilla-srcdir/editusers.cgi
+--- bugzilla-srcdir.orig//editusers.cgi	2010-11-12 10:26:23.832939184 +0100
++++ bugzilla-srcdir/editusers.cgi	2010-11-12 10:28:19.721916586 +0100
 @@ -683,7 +683,7 @@
      ThrowCodeError('action_unrecognized', $vars);
  }
@@ -953,9 +952,9 @@ diff -Naur a/editusers.cgi b/editusers.cgi
  
  ###########################################################################
  # Helpers
-diff -Naur a/editvalues.cgi b/editvalues.cgi
---- a/editvalues.cgi	2010-05-14 16:35:51.000000000 +0200
-+++ b/editvalues.cgi	2010-08-08 15:36:58.211002100 +0200
+diff -Naur bugzilla-srcdir.orig//editvalues.cgi bugzilla-srcdir/editvalues.cgi
+--- bugzilla-srcdir.orig//editvalues.cgi	2010-11-12 10:26:23.852923792 +0100
++++ bugzilla-srcdir/editvalues.cgi	2010-11-12 10:28:19.721916586 +0100
 @@ -39,7 +39,7 @@
      $vars->{'values'} = $vars->{'field'}->legal_values;
      $template->process("admin/fieldvalues/list.html.tmpl", $vars)
@@ -1001,9 +1000,9 @@ diff -Naur a/editvalues.cgi b/editvalues.cgi
  }
  
  
-diff -Naur a/editversions.cgi b/editversions.cgi
---- a/editversions.cgi	2009-04-10 11:36:43.000000000 +0200
-+++ b/editversions.cgi	2010-08-08 15:36:58.211002100 +0200
+diff -Naur bugzilla-srcdir.orig//editversions.cgi bugzilla-srcdir/editversions.cgi
+--- bugzilla-srcdir.orig//editversions.cgi	2010-11-12 10:26:23.461427610 +0100
++++ bugzilla-srcdir/editversions.cgi	2010-11-12 10:28:19.721916586 +0100
 @@ -80,7 +80,7 @@
  
      $template->process("admin/versions/select-product.html.tmpl", $vars)
@@ -1076,9 +1075,9 @@ diff -Naur a/editversions.cgi b/editversions.cgi
  }
  
  #
-diff -Naur a/editworkflow.cgi b/editworkflow.cgi
---- a/editworkflow.cgi	2008-07-02 21:10:17.000000000 +0200
-+++ b/editworkflow.cgi	2010-08-08 15:36:58.211002100 +0200
+diff -Naur bugzilla-srcdir.orig//editworkflow.cgi bugzilla-srcdir/editworkflow.cgi
+--- bugzilla-srcdir.orig//editworkflow.cgi	2010-11-12 10:26:23.952922193 +0100
++++ bugzilla-srcdir/editworkflow.cgi	2010-11-12 10:28:19.721916586 +0100
 @@ -67,7 +67,7 @@
  
      $template->process("admin/workflow/$filename.html.tmpl", $vars)
@@ -1088,10 +1087,10 @@ diff -Naur a/editworkflow.cgi b/editworkflow.cgi
  }
  
  if ($action eq 'edit') {
-diff -Naur a/email_in.pl b/email_in.pl
---- a/email_in.pl	2010-08-04 02:19:38.000000000 +0200
-+++ b/email_in.pl	2010-08-08 15:36:58.211002100 +0200
-@@ -393,7 +393,7 @@
+diff -Naur bugzilla-srcdir.orig//email_in.pl bugzilla-srcdir/email_in.pl
+--- bugzilla-srcdir.orig//email_in.pl	2010-11-12 10:26:39.776939670 +0100
++++ bugzilla-srcdir/email_in.pl	2010-11-12 10:28:19.721916586 +0100
+@@ -395,7 +395,7 @@
      print STDERR "$msg\n";
      # We exit with a successful value, because we don't want the MTA
      # to *also* send a failure notice.
@@ -1100,9 +1099,9 @@ diff -Naur a/email_in.pl b/email_in.pl
  }
  
  ###############
-diff -Naur a/enter_bug.cgi b/enter_bug.cgi
---- a/enter_bug.cgi	2010-03-14 23:45:58.000000000 +0100
-+++ b/enter_bug.cgi	2010-08-08 15:36:58.211002100 +0200
+diff -Naur bugzilla-srcdir.orig//enter_bug.cgi bugzilla-srcdir/enter_bug.cgi
+--- bugzilla-srcdir.orig//enter_bug.cgi	2010-11-12 10:26:23.481418058 +0100
++++ bugzilla-srcdir/enter_bug.cgi	2010-11-12 10:28:19.725914769 +0100
 @@ -115,7 +115,7 @@
              print $cgi->header();
              $template->process("global/choose-classification.html.tmpl", $vars)
@@ -1121,9 +1120,9 @@ diff -Naur a/enter_bug.cgi b/enter_bug.cgi
      } else {
          # Only one product exists.
          $product = $enterable_products[0];
-diff -Naur a/importxml.pl b/importxml.pl
---- a/importxml.pl	2009-12-18 00:31:53.000000000 +0100
-+++ b/importxml.pl	2010-08-08 15:36:58.215002942 +0200
+diff -Naur bugzilla-srcdir.orig//importxml.pl bugzilla-srcdir/importxml.pl
+--- bugzilla-srcdir.orig//importxml.pl	2010-11-12 10:26:39.432919924 +0100
++++ bugzilla-srcdir/importxml.pl	2010-11-12 10:28:19.725914769 +0100
 @@ -157,7 +157,7 @@
      my @to = ( $params->{"maintainer"}, $exporter);
      Debug( $message, ERR_LEVEL );
@@ -1133,9 +1132,9 @@ diff -Naur a/importxml.pl b/importxml.pl
  }
  
  # This subroutine handles flags for process_bug. It is generic in that
-diff -Naur a/index.cgi b/index.cgi
---- a/index.cgi	2009-10-09 06:31:09.000000000 +0200
-+++ b/index.cgi	2010-08-08 15:36:58.215002942 +0200
+diff -Naur bugzilla-srcdir.orig//index.cgi bugzilla-srcdir/index.cgi
+--- bugzilla-srcdir.orig//index.cgi	2010-11-12 10:26:25.268914746 +0100
++++ bugzilla-srcdir/index.cgi	2010-11-12 10:28:19.725914769 +0100
 @@ -64,7 +64,7 @@
      unless (Bugzilla->params->{'urlbase'}) {
          $template->process('welcome-admin.html.tmpl')
@@ -1145,9 +1144,9 @@ diff -Naur a/index.cgi b/index.cgi
      }
      # Inform the administrator about new releases, if any.
      $vars->{'release'} = Bugzilla::Update::get_notifications();
-diff -Naur a/install-module.pl b/install-module.pl
---- a/install-module.pl	2010-04-21 00:17:50.000000000 +0200
-+++ b/install-module.pl	2010-08-08 15:36:58.215002942 +0200
+diff -Naur bugzilla-srcdir.orig//install-module.pl bugzilla-srcdir/install-module.pl
+--- bugzilla-srcdir.orig//install-module.pl	2010-04-21 00:17:50.000000000 +0200
++++ bugzilla-srcdir/install-module.pl	2010-11-12 10:28:19.725914769 +0100
 @@ -54,7 +54,7 @@
  if (ON_WINDOWS) {
      print "\nYou cannot run this script on Windows. Please follow instructions\n";
@@ -1174,9 +1173,9 @@ diff -Naur a/install-module.pl b/install-module.pl
  }
  
  if ($switch{'all'} || $switch{'upgrade-all'}) {
-diff -Naur a/post_bug.cgi b/post_bug.cgi
---- a/post_bug.cgi	2010-04-07 05:31:29.000000000 +0200
-+++ b/post_bug.cgi	2010-08-08 15:36:58.215002942 +0200
+diff -Naur bugzilla-srcdir.orig//post_bug.cgi bugzilla-srcdir/post_bug.cgi
+--- bugzilla-srcdir.orig//post_bug.cgi	2010-11-12 10:26:39.724915541 +0100
++++ bugzilla-srcdir/post_bug.cgi	2010-11-12 10:28:19.725914769 +0100
 @@ -80,7 +80,7 @@
          print $cgi->header();
          $template->process("bug/create/confirm-create-dupe.html.tmpl", $vars)
@@ -1195,9 +1194,9 @@ diff -Naur a/post_bug.cgi b/post_bug.cgi
  }
  
  umask 0;
-diff -Naur a/process_bug.cgi b/process_bug.cgi
---- a/process_bug.cgi	2010-04-07 05:31:29.000000000 +0200
-+++ b/process_bug.cgi	2010-08-08 15:36:58.215002942 +0200
+diff -Naur bugzilla-srcdir.orig//process_bug.cgi bugzilla-srcdir/process_bug.cgi
+--- bugzilla-srcdir.orig//process_bug.cgi	2010-11-12 10:26:25.605917372 +0100
++++ bugzilla-srcdir/process_bug.cgi	2010-11-12 10:28:19.725914769 +0100
 @@ -177,7 +177,7 @@
          # Warn the user about the mid-air collision and ask them what to do.
          $template->process("bug/process/midair.html.tmpl", $vars)
@@ -1225,9 +1224,9 @@ diff -Naur a/process_bug.cgi b/process_bug.cgi
      }
  } elsif ($action ne 'nothing') {
      ThrowCodeError("invalid_post_bug_submit_action");
-diff -Naur a/report.cgi b/report.cgi
---- a/report.cgi	2010-02-18 20:33:13.000000000 +0100
-+++ b/report.cgi	2010-08-08 15:36:58.215002942 +0200
+diff -Naur bugzilla-srcdir.orig//report.cgi bugzilla-srcdir/report.cgi
+--- bugzilla-srcdir.orig//report.cgi	2010-11-12 10:26:24.124922158 +0100
++++ bugzilla-srcdir/report.cgi	2010-11-12 10:28:19.725914769 +0100
 @@ -42,7 +42,7 @@
        ($params ? "&$params" : "");
  
@@ -1255,30 +1254,9 @@ diff -Naur a/report.cgi b/report.cgi
  
  
  sub get_names {
-diff -Naur a/reports.cgi b/reports.cgi
---- a/reports.cgi	2009-10-24 07:21:06.000000000 +0200
-+++ b/reports.cgi	2010-08-08 15:36:58.215002942 +0200
-@@ -94,7 +94,7 @@
- 
-     $template->process('reports/old-charts.html.tmpl', $vars)
-       || ThrowTemplateError($template->error());
--    exit;
-+    exit(1);
- }
- else {
-     my $product = $cgi->param('product');
-@@ -129,7 +129,7 @@
- 
-     $template->process('reports/old-charts.html.tmpl', $vars)
-       || ThrowTemplateError($template->error());
--    exit;
-+    exit(1);
- }
- 
- #####################
-diff -Naur a/request.cgi b/request.cgi
---- a/request.cgi	2010-08-05 00:01:37.000000000 +0200
-+++ b/request.cgi	2010-08-08 15:36:58.215002942 +0200
+diff -Naur bugzilla-srcdir.orig//request.cgi bugzilla-srcdir/request.cgi
+--- bugzilla-srcdir.orig//request.cgi	2010-11-12 10:26:39.704930703 +0100
++++ bugzilla-srcdir/request.cgi	2010-11-12 10:28:19.725914769 +0100
 @@ -87,7 +87,7 @@
      $template->process('request/queue.html.tmpl', $vars)
        || ThrowTemplateError($template->error());
@@ -1288,9 +1266,9 @@ diff -Naur a/request.cgi b/request.cgi
  
  ################################################################################
  # Functions
-diff -Naur a/sanitycheck.cgi b/sanitycheck.cgi
---- a/sanitycheck.cgi	2009-12-18 00:31:53.000000000 +0100
-+++ b/sanitycheck.cgi	2010-08-08 15:36:58.215002942 +0200
+diff -Naur bugzilla-srcdir.orig//sanitycheck.cgi bugzilla-srcdir/sanitycheck.cgi
+--- bugzilla-srcdir.orig//sanitycheck.cgi	2010-11-12 10:26:23.932915961 +0100
++++ bugzilla-srcdir/sanitycheck.cgi	2010-11-12 10:28:19.725914769 +0100
 @@ -107,7 +107,7 @@
  
      $template->process('global/footer.html.tmpl', $vars)
@@ -1309,18 +1287,18 @@ diff -Naur a/sanitycheck.cgi b/sanitycheck.cgi
  }
  
  ###########################################################################
-diff -Naur a/showattachment.cgi b/showattachment.cgi
---- a/showattachment.cgi	2007-10-19 08:46:11.000000000 +0200
-+++ b/showattachment.cgi	2010-08-08 15:36:58.215002942 +0200
+diff -Naur bugzilla-srcdir.orig//showattachment.cgi bugzilla-srcdir/showattachment.cgi
+--- bugzilla-srcdir.orig//showattachment.cgi	2010-11-12 10:26:24.060929332 +0100
++++ bugzilla-srcdir/showattachment.cgi	2010-11-12 10:28:19.725914769 +0100
 @@ -37,4 +37,4 @@
  print $cgi->redirect(-location=>"attachment.cgi?id=$id",
                       -status=>'301 Permanent Redirect');
  
 -exit;
 +exit(0);
-diff -Naur a/show_bug.cgi b/show_bug.cgi
---- a/show_bug.cgi	2009-11-10 17:31:48.000000000 +0100
-+++ b/show_bug.cgi	2010-08-08 15:36:58.215002942 +0200
+diff -Naur bugzilla-srcdir.orig//show_bug.cgi bugzilla-srcdir/show_bug.cgi
+--- bugzilla-srcdir.orig//show_bug.cgi	2010-11-12 10:26:39.684930804 +0100
++++ bugzilla-srcdir/show_bug.cgi	2010-11-12 10:28:19.725914769 +0100
 @@ -46,7 +46,7 @@
      print Bugzilla->cgi->header();
      $template->process("bug/choose.html.tmpl", $vars) ||
@@ -1330,9 +1308,9 @@ diff -Naur a/show_bug.cgi b/show_bug.cgi
  }
  
  my $format = $template->get_format("bug/show", scalar $cgi->param('format'), 
-diff -Naur a/testagent.cgi b/testagent.cgi
---- a/testagent.cgi	2007-02-11 01:12:24.000000000 +0100
-+++ b/testagent.cgi	2010-08-08 15:36:58.215002942 +0200
+diff -Naur bugzilla-srcdir.orig//testagent.cgi bugzilla-srcdir/testagent.cgi
+--- bugzilla-srcdir.orig//testagent.cgi	2007-02-11 01:12:24.000000000 +0100
++++ bugzilla-srcdir/testagent.cgi	2010-11-12 10:28:19.725914769 +0100
 @@ -20,5 +20,5 @@
  use strict;
  print "content-type:text/plain\n\n";
@@ -1340,9 +1318,9 @@ diff -Naur a/testagent.cgi b/testagent.cgi
 -exit;
 +exit(0);
  
-diff -Naur a/token.cgi b/token.cgi
---- a/token.cgi	2009-10-09 06:31:09.000000000 +0200
-+++ b/token.cgi	2010-08-08 15:36:58.215002942 +0200
+diff -Naur bugzilla-srcdir.orig//token.cgi bugzilla-srcdir/token.cgi
+--- bugzilla-srcdir.orig//token.cgi	2010-11-12 10:26:39.388920267 +0100
++++ bugzilla-srcdir/token.cgi	2010-11-12 10:28:19.725914769 +0100
 @@ -169,7 +169,7 @@
      ThrowCodeError("unknown_action", { action => $action });
  }
@@ -1352,9 +1330,9 @@ diff -Naur a/token.cgi b/token.cgi
  
  ################################################################################
  # Functions
-diff -Naur a/votes.cgi b/votes.cgi
---- a/votes.cgi	2010-04-07 05:31:30.000000000 +0200
-+++ b/votes.cgi	2010-08-08 15:36:58.215002942 +0200
+diff -Naur bugzilla-srcdir.orig//votes.cgi bugzilla-srcdir/votes.cgi
+--- bugzilla-srcdir.orig//votes.cgi	2010-11-12 10:26:23.872946250 +0100
++++ bugzilla-srcdir/votes.cgi	2010-11-12 10:28:19.725914769 +0100
 @@ -91,7 +91,7 @@
      ThrowCodeError("unknown_action", {action => $action});
  }
